export const description = '在本节中，我们将学习如何通过配置文件配置服务器。'

## 通过环境文件配置服务器

因为频繁修改代码容易引起报错，蝙蝠侠想要通过使用环境文件来配置服务器。

## 环境变量

- `ROBYN_PORT`：设置 Robyn 服务器监听的端口。
  - 默认值：`8080`
  - 示例：`ROBYN_PORT=3000`
- `ROBYN_HOST`：设置 Robyn 服务器的主机地址。
  - 默认值：`127.0.0.1`
  - 示例：`ROBYN_HOST=0.0.0.0`
- `ROBYN_BROWSER_OPEN`：启动成功后是否自动打开浏览器。
  - 默认值：`False`
  - 示例：`ROBYN_BROWSER_OPEN=True`
- `ROBYN_DEV_MODE`：是否开启开发者模式。
  - 默认值：`False`
  - 示例：`ROBYN_DEV_MODE=True`
- `ROBYN_MAX_PAYLOAD_SIZE`：设置请求的最大负载大小（以字节为单位）。
  - 默认值：1000000 bytes
  - 示例：`ROBYN_MAX_PAYLOAD_SIZE=1000000`

您可以使用 `robyn.env` 文件自动加载这些环境变量。

这些环境变量通常存储在项目根目录下的 `robyn.env` 文件中。服务器在启动时会自动读取该文件，并据此进行配置。

更多关于项目结构和 `robyn.env` 的使用方法，请参考以下文档：

```bash {{title: '项目结构示例'}}
--project/
  --robyn.env
  --index.py
  ...
```

`robyn.env` 文件示例如下：

```bash {{ title: '简易 Robyn.env' }}
ROBYN_PORT=8080
ROBYN_HOST=127.0.0.1
RANDOM_ENV=123
ROBYN_BROWSER_OPEN=True
ROBYN_DEV_MODE=True
ROBYN_MAX_PAYLOAD_SIZE=1000000
```

随着 Web 应用程序的顺利部署和运行，蝙蝠侠拥有了一个强大的新工具。Robyn 框架为他提供了创建高效打击犯罪应用所需的灵活性、可扩展性和高性能，使他在保护哥谭市的战斗中获得了技术上的优势。

## 下一步

蝙蝠侠：罗宾。请告诉我更多。  
Robyn：接下来我们来了解中间件和 `Events` 事件吧！

- [中间件](/documentation/zh/api_reference/middlewares)
